# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib import admin
from django.conf.urls import url
from django.core import serializers
from django.http import HttpResponse, request

from .models import *
from .forms import LocationForm, CountryCodeForm, CountryForm, CityForm, StateForm


class CityAdmin(admin.ModelAdmin):
    form = CityForm
    prepopulated_fields = {"slug": ("name",)}

admin.site.register(City, CityAdmin)


class StateAdmin(admin.ModelAdmin):
    form = StateForm
    prepopulated_fields = {"slug": ("name",)}

admin.site.register(State, StateAdmin)


class CountryAdmin(admin.ModelAdmin):
    form = CountryForm
    prepopulated_fields = {"slug": ("name",)}

admin.site.register(Country, CountryAdmin)


class CountryCodeAdmin(admin.ModelAdmin):
    form = CountryCodeForm
    prepopulated_fields = {"slug": ("name",)}

admin.site.register(CountryCode, CountryCodeAdmin)


class LocationAdmin(admin.ModelAdmin):
    form = LocationForm
    model = Location
    prepopulated_fields = {"slug": ("name",)}

    def __init__(self, model, admin_site):
        self.form.admin_site = admin_site
        super(LocationAdmin, self).__init__(model, admin_site)

    def get_urls(self):
        urls = super(LocationAdmin, self).get_urls()
        my_urls = [
            url(r'^cities/', self.admin_site.admin_view(self.cities), name='city'),
            url(r'^states/', self.admin_site.admin_view(self.states), name='state'),
        ]
        return my_urls + urls

    def cities(self):
        data = serializers.serialize('json', City.objects.filter(estado=request.GET.get('state')).all())
        return HttpResponse(data, content_type='application/json')

    def states(self, request):
        data = serializers.serialize('json', State.objects.filter(pais=request.GET.get('country')).all())
        return HttpResponse(data, content_type='application/json')




from django.conf.urls import url, include
from rest_framework import routers

from location.views import CityViewSet, StateViewSet, CountryViewSet, CountryCodeViewSet

router = routers.DefaultRouter()
router.register(r'Cities', CityViewSet)
router.register(r'States', StateViewSet)
router.register(r'Countries', CountryViewSet)
router.register(r'CountriesCodes', CountryCodeViewSet)

urlpatterns = [
    url(r'^', include(router.urls)),
]


# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from rest_framework import viewsets, filters
from .models import Location, City, State, Country, CountryCode
from .serializers import LocationSerializer, CitySerializer, StateSerializer, CountrySerializer, CountryCodeSerializer

# Create your views here.


class CityViewSet(viewsets.ModelViewSet):
    model = City
    queryset = model.objects.all()
    serializer_class = CitySerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = ('language', 'slug', 'state__id', 'state__code')
    http_method_names = ['get', ]


class StateViewSet(viewsets.ModelViewSet):
    model = State
    queryset = model.objects.all()
    serializer_class = StateSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = ('language', 'slug', 'country__id', 'country__code__code')
    ordering_fields = ('name',)
    http_method_names = ['get', ]


class CountryViewSet(viewsets.ModelViewSet):
    model = Country
    queryset = model.objects.all()
    serializer_class = CountrySerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = ('language', 'slug', 'code__code')
    ordering_fields = ('name',)
    http_method_names = ['get', ]


class CountryCodeViewSet(viewsets.ModelViewSet):
    model = CountryCode
    queryset = model.objects.all()
    serializer_class = CountryCodeSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = ('language',)
    ordering_fields = ('name',)
    http_method_names = ['get', ]


class LocationViewSet(viewsets.ModelViewSet):
    model = Location
    serializer_class = LocationSerializer
    filter_backends = (filters.DjangoFilterBackend,)
    filter_fields = (
        'language',
        'neighborhood',
        'postal_code',
        'address',
        'complement',
        'city__id',
        'city__state__id',
        'city__state__code',
        'city__state__country__id',
        'city__state__country__code__code'
    )
    ordering_fields = ('address',)
    http_method_names = ['get', ]




# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-02-19 13:29
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=255, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('language', models.CharField(choices=[(b'ar', 'Arabe'), (b'cn', 'Chines'), (b'en', 'English'), (b'pt', 'Portugu\xeas'), (b'es', 'Espanhol'), (b'ru', 'Russia')], max_length=2)),
                ('name', models.CharField(max_length=50, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=255, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('language', models.CharField(choices=[(b'ar', 'Arabe'), (b'cn', 'Chines'), (b'en', 'English'), (b'pt', 'Portugu\xeas'), (b'es', 'Espanhol'), (b'ru', 'Russia')], max_length=2)),
                ('name', models.CharField(max_length=50, unique=True)),
                ('flag', models.FileField(blank=True, null=True, upload_to=b'')),
            ],
        ),
        migrations.CreateModel(
            name='CountryCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=255, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=255, unique=True)),
                ('code', models.CharField(max_length=2, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='State',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=255, unique=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('language', models.CharField(choices=[(b'ar', 'Arabe'), (b'cn', 'Chines'), (b'en', 'English'), (b'pt', 'Portugu\xeas'), (b'es', 'Espanhol'), (b'ru', 'Russia')], max_length=2)),
                ('name', models.CharField(max_length=50, unique=True)),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='location.CountryCode')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='location.Country')),
            ],
        ),
        migrations.AddField(
            model_name='country',
            name='code',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='location.CountryCode'),
        ),
        migrations.AddField(
            model_name='city',
            name='state',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='location.State'),
        ),
        migrations.AlterUniqueTogether(
            name='state',
            unique_together=set([('language', 'code')]),
        ),
        migrations.AlterUniqueTogether(
            name='country',
            unique_together=set([('language', 'code')]),
        ),
    ]
